@@ -124,5 +124,7 @@ class EngineFacade(object):
         :type conf: oslo.config.cfg.ConfigOpts
 
         """
+        LOG.debug('making connection using connect string: %s',
+                  connection_string)
         return cls(sql_connection=connection_string,
                    **dict(conf.database.items()))
